<?php
/*
Plugin Name: Notification of the creation of a new admin user. [DAILY RIPORT]
Description: Ez a bővítmény egyedi WordPress értesítéseket küld, amikor egy új adminisztrátor jogkörű felhasználó regisztrál a weboldalon. A felhasználó létrejöttét követően azonnali értesítés meg az előre megadott e-mail címre, ezáltal lehetővé téve a gyors és hatékony reagálást az adminisztrátori jogosultságokkal rendelkező új felhasználók regisztrációira.
Author: Adam Szucs
Version: 1.0
*/

/**
 * Notify admin when a new admin user account is created
 */
add_action( 'user_register', 'admin_created_user_notification', 10, 1 );
function admin_created_user_notification( $user_id ) {
    $user = get_userdata( $user_id );

    // Ellenőrizze, hogy az új felhasználónak adminisztrátori jogosultságai vannak-e
    if ( in_array( 'administrator', (array) $user->roles ) ) {
        // Adminisztrátor e-mail címe
        $admin_email = 'info@valami.hu'; // Ide írd be az admin e-mail címét

        // Értesítés tárgya és üzenete
        $subject = 'Új adminisztrátori felhasználó regisztrált';
        $message = 'Az alábbi adminisztrátori felhasználó regisztrált: ' . $user->user_email;

        // Elküldjük az értesítést
        wp_mail( $admin_email, $subject, $message );
    }
}

// Funkció a napi értesítés küldéséhez
function send_daily_admin_users_list() {
    // Adminisztrátor e-mail címe, ahova a listát küldjük
    $admin_email = 'info@valami.hu'; // Ide írd be a címét

    // Lekérdezzük az adminisztrátor jogosultságokkal rendelkező felhasználók e-mail címeit
    $admin_users = get_users( array( 'role' => 'administrator' ) );

    // Létrehozunk egy üzenetet a felhasználók e-mail címeivel
    $message = 'Adminisztrátori felhasználók e-mail címei: ';
    foreach ( $admin_users as $admin_user ) {
        $message .= $admin_user->user_email . ' ';
    }

    // Elküldjük az értesítést
    wp_mail( $admin_email, 'A weboldal adminisztrátorainak listája', $message );
}

// Napi cron job hozzáadása
add_action( 'init', 'schedule_daily_admin_users_list' );
function schedule_daily_admin_users_list() {
    if ( ! wp_next_scheduled( 'send_daily_admin_users_list_event' ) ) {
        wp_schedule_event( current_time( 'timestamp' ), 'daily', 'send_daily_admin_users_list_event' );
    }
}

// Naponta egyszer lefutó cron job
add_action( 'send_daily_admin_users_list_event', 'send_daily_admin_users_list' );